@@ -21,22 +21,19 @@
 
 from __future__ import annotations
 
-import logging
-
 from typing import TYPE_CHECKING
 
-import click
-
+from molecule.click_cfg import click_command_ex, common_options
 from molecule.command import base
+from molecule.reporting.definitions import CompletionState
 
 
 if TYPE_CHECKING:
+    import click
+
     from molecule.types import CommandArgs, MoleculeArgs
 
 
-LOG = logging.getLogger(__name__)
-
-
 class Cleanup(base.Base):
     """Cleanup Command Class."""
 
@@ -48,39 +45,36 @@ class Cleanup(base.Base):
         """
         if self._config.provisioner:
             if not self._config.provisioner.playbooks.cleanup:
-                msg = "Skipping, cleanup playbook not configured."
-                LOG.warning(msg)
+                message = "Missing playbook"
+                note = f"Remove from {self._config.subcommand}_sequence to suppress"
+                self._config.scenario.results.add_completion(
+                    CompletionState.missing(message=message, note=note),
+                )
                 return
 
             self._config.provisioner.cleanup()
 
 
-@base.click_command_ex()
-@click.pass_context
-@base.click_command_options
-def cleanup(
-    ctx: click.Context,
-    /,
-    scenario_name: list[str] | None,
-    exclude: list[str],
-    *,
-    __all: bool,
-    report: bool,
-) -> None:  # pragma: no cover
-    """Use the provisioner to cleanup any changes.
-
-    Any changes made to external systems during the stages of testing.
+@click_command_ex()
+@common_options()
+def cleanup(ctx: click.Context) -> None:  # pragma: no cover
+    """Use the provisioner to cleanup any changes made to external systems during the stages of testing.
 
     Args:
         ctx: Click context object holding commandline arguments.
-        scenario_name: Name of the scenario to target.
-        exclude: Name of the scenarios to avoid targeting.
-        __all: Whether molecule should target scenario_name or all scenarios.
-        report: Whether to show an after-run summary report.
     """
     args: MoleculeArgs = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
-    command_args: CommandArgs = {"subcommand": subcommand, "report": report}
+    command_args: CommandArgs = {
+        "command_borders": ctx.params["command_borders"],
+        "report": ctx.params["report"],
+        "shared_state": ctx.params["shared_state"],
+        "subcommand": subcommand,
+    }
+
+    __all = ctx.params["all"]
+    exclude = ctx.params["exclude"]
+    scenario_name = ctx.params["scenario_name"]
 
     if __all:
         scenario_name = None
