@@ -23,7 +23,6 @@ from __future__ import annotations
 
 import fcntl
 import fnmatch
-import logging
 import os
 import shutil
 
@@ -32,18 +31,15 @@ from pathlib import Path
 from time import sleep
 from typing import TYPE_CHECKING
 
-from molecule import scenarios, util
+from molecule import logger, scenarios, util
 from molecule.constants import RC_TIMEOUT
 from molecule.exceptions import MoleculeError
+from molecule.reporting.definitions import ScenarioResults
 from molecule.text import checksum
 
 
 if TYPE_CHECKING:
     from molecule.config import Config
-    from molecule.types import ScenarioResult
-
-
-LOG = logging.getLogger(__name__)
 
 
 class Scenario:
@@ -57,7 +53,7 @@ class Scenario:
         """
         self._lock = None
         self.config = config
-        self.results: list[ScenarioResult] = []
+        self.results: ScenarioResults = ScenarioResults(name=self.name, actions=[])
         self._setup()
 
     def __repr__(self) -> str:
@@ -71,7 +67,8 @@ class Scenario:
     def _remove_scenario_state_directory(self) -> None:
         """Remove scenario cached disk stored state."""
         directory = str(Path(self.ephemeral_directory).parent)
-        LOG.info("Removing %s", directory)
+        scenario_log = logger.get_scenario_logger(__name__, self.name, "scenario")
+        scenario_log.info("Removing %s", directory)
         shutil.rmtree(directory)
 
     def prune(self) -> None:
@@ -82,7 +79,8 @@ class Scenario:
         files declared as "safe_files" in the ``driver`` configuration
         declared in ``molecule.yml``.
         """
-        LOG.info("Pruning extra files from scenario ephemeral directory")
+        scenario_log = logger.get_scenario_logger(__name__, self.name, "scenario")
+        scenario_log.info("Pruning extra files from scenario ephemeral directory")
 
         safe_files = [
             self.config.state.state_file,
@@ -157,14 +155,16 @@ class Scenario:
                         break
                     except OSError:
                         delay = 30 * i
-                        LOG.warning(
+                        scenario_log = logger.get_scenario_logger(__name__, self.name, "scenario")
+                        scenario_log.warning(
                             "Retrying to acquire lock on %s, waiting for %s seconds",
                             path,
                             delay,
                         )
                         sleep(delay)
                 else:
-                    LOG.warning("Timedout trying to acquire lock on %s", path)
+                    scenario_log = logger.get_scenario_logger(__name__, self.name, "scenario")
+                    scenario_log.warning("Timedout trying to acquire lock on %s", path)
                     raise MoleculeError(code=RC_TIMEOUT)
 
         return path.absolute().as_posix()
@@ -194,12 +194,7 @@ class Scenario:
         Returns:
             The directory containing the scenario's inventory.
         """
-        if self.config.shared_inventory and not self.config.is_parallel:
-            ephemeral = Path(self.shared_ephemeral_directory)
-        else:
-            ephemeral = Path(self.ephemeral_directory)
-
-        return str(ephemeral / "inventory")
+        return str(Path(self.ephemeral_directory) / "inventory")
 
     @property
     def check_sequence(self) -> list[str]:
